pub struct BoundingBox {
pub min_lat: f64,
pub min_lon: f64,
pub max_lat: f64,
pub max_lon: f64,
}Expand description
A geographic bounding box for filtering tiles during preload.
Coordinates are in decimal degrees (WGS84).
Fields
min_lat: f64Minimum latitude (southern boundary).
min_lon: f64Minimum longitude (western boundary).
max_lat: f64Maximum latitude (northern boundary).
max_lon: f64Maximum longitude (eastern boundary).
Implementations
Sourceimpl BoundingBox
impl BoundingBox
Sourcepub fn new(min_lat: f64, min_lon: f64, max_lat: f64, max_lon: f64) -> Self
pub fn new(min_lat: f64, min_lon: f64, max_lat: f64, max_lon: f64) -> Self
Create a new bounding box.
Arguments
min_lat- Southern boundary latitudemin_lon- Western boundary longitudemax_lat- Northern boundary latitudemax_lon- Eastern boundary longitude
Sourcepub fn overlaps_tile(&self, tile_lat: i32, tile_lon: i32) -> bool
pub fn overlaps_tile(&self, tile_lat: i32, tile_lon: i32) -> bool
Check if this bounding box overlaps with a 1°×1° tile.
A tile at (tile_lat, tile_lon) covers the area
[tile_lat, tile_lat+1) × [tile_lon, tile_lon+1).